@@ -12,7 +12,7 @@ use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 package XML::Ant::BuildFile::Project;
 
 BEGIN {
-    $XML::Ant::BuildFile::Project::VERSION = '0.202';
+    $XML::Ant::BuildFile::Project::VERSION = '0.203';
 }
 
 # ABSTRACT: consume Ant build files
@@ -58,9 +58,10 @@ has '+_file' => ( isa => 'FileStr', coerce => 1 );
     );
 
     has targets => (
-        isa => ArrayRef [Str],
-        traits      => ['XPathValueList'],
-        xpath_query => '/project/target/@name',
+        isa         => 'HashRef[XML::Ant::BuildFile::Project::Target]',
+        traits      => ['XPathObjectMap'],
+        xpath_query => '/project/target[@name]',
+        xpath_key   => './@name',
     );
 }
 
@@ -93,7 +94,7 @@ XML::Ant::BuildFile::Project - consume Ant build files
 
 =head1 VERSION
 
-version 0.202
+version 0.203
 
 =head1 SYNOPSIS
 
@@ -132,7 +133,8 @@ L<XML::Ant::BuildFile::Project::FileList|XML::Ant::BuildFile::Project::FileList>
 
 =head2 targets
 
-Array reference of target names from the build file.
+Array reference of target L<XML::Rabbit::Node|XML::Rabbit::Node>s
+from the build file.
 
 =head2 properties
 
